@@ -16,7 +16,7 @@
  */
 
 /*
- * $Id: XMLUni.cpp 1726088 2016-01-21 20:18:52Z scantor $
+ * $Id: XMLUni.cpp 1799525 2017-06-21 22:21:02Z scantor $
  */
 
 
@@ -316,6 +316,11 @@ const XMLCh XMLUni::fgStandaloneString[] =
     chLatin_s, chLatin_t, chLatin_a, chLatin_n, chLatin_d, chLatin_a, chLatin_l, chLatin_o, chLatin_n, chLatin_e, chNull
 };
 
+const XMLCh XMLUni::fgVersion1[] =
+{
+    chDigit_1, chPeriod, chNull
+};
+
 const XMLCh XMLUni::fgVersion1_0[] =
 {
     chDigit_1, chPeriod, chDigit_0, chNull
@@ -1044,7 +1049,8 @@ const XMLCh XMLUni::fgXercesLoadSchema[] =
     ,   chLatin_v, chLatin_a, chLatin_l, chLatin_i, chLatin_d
     ,   chLatin_a, chLatin_t, chLatin_i, chLatin_n, chLatin_g, chForwardSlash
     ,   chLatin_l, chLatin_o, chLatin_a, chLatin_d, chDash
-    ,   chLatin_s, chLatin_c, chLatin_h, chLatin_e, chLatin_m, chLatin_a, chNull
+    ,   chLatin_s, chLatin_c, chLatin_h, chLatin_e, chLatin_m, chLatin_a
+    ,   chNull
 };
 
 //Xerces: http://apache.org/xml/features/validation/identity-constraint-checking
